"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const i18next_1 = require("i18next");
const isomorphic_git_1 = tslib_1.__importDefault(require("isomorphic-git"));
const extractSuggestionFromError_1 = tslib_1.__importDefault(require("./extractSuggestionFromError"));
const validateGitRepositoryURL_1 = tslib_1.__importDefault(require("./validateGitRepositoryURL"));
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("../magento2/functions/terminalHelpers");
const validateURL = async (url) => {
    const error = await (0, validateGitRepositoryURL_1.default)(url);
    (0, terminalHelpers_1.simpleLog)(error instanceof isomorphic_git_1.default.Errors.UrlParseError
        ? (0, i18next_1.t)('domain.git_repository_url.is_invalid')
        : (0, i18next_1.t)('domain.git_repository_url.was_not_found'));
    return error;
};
const suggestURL = async (url) => {
    const suggestion = await (0, extractSuggestionFromError_1.default)(url);
    return suggestion !== null && suggestion !== void 0 ? suggestion : null;
};
/** Gets a git repository URL from user's input. */
const getGitRepositoryURL = async (message) => {
    // URL
    const answer = await (0, prompts_1.text)({
        message
    });
    if ((0, prompts_1.isCancel)(answer)) {
        (0, prompts_1.cancel)('Installation cancelled');
        return '';
    }
    // Validation
    const validateResult = await validateURL(answer);
    if (!validateResult)
        return answer;
    // Suggestion
    const suggestion = await suggestURL(validateResult);
    if (suggestion) {
        const answer = await (0, prompts_1.confirm)({
            message: (0, i18next_1.t)('domain.git_repository_url.suggestion', { suggestion })
        });
        if ((0, prompts_1.isCancel)(answer)) {
            (0, prompts_1.cancel)('Installation cancelled');
            return '';
        }
        if (answer)
            return suggestion;
    }
    return getGitRepositoryURL(message);
};
exports.default = getGitRepositoryURL;
//# sourceMappingURL=getGitRepositoryURL.js.map