"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const removeDocker_1 = tslib_1.__importDefault(require("./removeDocker"));
const terminalHelpers_1 = require("../functions/terminalHelpers");
const prompts_1 = require("@clack/prompts");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const i18next_1 = require("i18next");
/** Handles Magento 2 Docker Image installation */
const installMagentoImage = async (magentoDirName, magentoDomainName, writeLog) => {
    const options = {
        cwd: magentoDirName
    };
    const sp = (0, prompts_1.spinner)();
    return new Promise((resolve) => {
        const curl = (0, child_process_1.spawn)('curl', [
            '-s',
            'https://raw.githubusercontent.com/markshust/docker-magento/master/lib/onelinesetup'
        ], options);
        const bash = (0, child_process_1.spawn)('bash', ['-s', '--', magentoDomainName], options);
        let stdout = '';
        (0, prompts_1.note)((0, i18next_1.t)('command.generate_store.magento.note_long'));
        sp.start(picocolors_1.default.cyan((0, i18next_1.t)('command.generate_store.progress.docker_start')));
        curl.stdout.pipe(bash.stdin);
        bash.stdout.on('data', (data) => {
            if (data.toString().toLowerCase().includes('system') &&
                data.toString().toLowerCase().includes('password')) {
                sp.stop(picocolors_1.default.yellow((0, i18next_1.t)('command.generate_store.magento.password')));
            }
            if (data.toString().includes('Restarting containers to apply updates')) {
                sp.start(picocolors_1.default.cyan((0, i18next_1.t)('command.generate_store.progress.docker_start')));
            }
        });
        bash.stderr.on('data', async (data) => {
            stdout += data.toString();
            if (stdout.includes('port is already allocated')) {
                sp.stop();
                (0, terminalHelpers_1.logSimpleErrorMessage)((0, i18next_1.t)('command.generate_store.magento.port_busy'));
                // delete the directory
                await (0, removeDocker_1.default)(magentoDirName);
            }
        });
        bash.on('exit', async (code) => {
            if (code === 0) {
                sp.stop(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.progress.docker_end')));
                resolve(1);
            }
            else {
                sp.stop(picocolors_1.default.red((0, i18next_1.t)('command.generate_store.progress.docker_failed')));
                if (stdout.includes('Project directory "/var/www/html/." is not empty')) {
                    (0, prompts_1.note)((0, i18next_1.t)('command.generate_store.magento.image_exists'));
                }
                // create a log file
                writeLog(stdout);
                (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.magento.failed_log'));
            }
        });
    });
};
exports.default = installMagentoImage;
//# sourceMappingURL=installMagentoImage.js.map