"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const fs_1 = tslib_1.__importDefault(require("fs"));
const prompts_1 = require("@clack/prompts");
const picocolors_1 = tslib_1.__importDefault(require("picocolors"));
const i18next_1 = require("i18next");
const terminalHelpers_1 = require("./terminalHelpers");
/** Install and enable GraphQL Magento module */
const handleGraphQL = async (magentoDirName, writeLog) => {
    const options = {
        cwd: magentoDirName,
        shell: true
    };
    const sp = (0, prompts_1.spinner)();
    const increaseQueryDepthAndComplexity = async () => {
        const data = fs_1.default.readFileSync(`${magentoDirName}/src/vendor/magento/module-graph-ql/etc/di.xml`, 'utf8');
        const result = data.replace(/<argument name="queryComplexity" xsi:type="number">300<\/argument>/g, '<argument name="queryComplexity" xsi:type="number">1500</argument>');
        fs_1.default.writeFileSync(`${magentoDirName}/src/vendor/magento/module-graph-ql/etc/di.xml`, result, 'utf8');
        fs_1.default.writeFileSync(`${magentoDirName}/src/vendor/magento/module-graph-ql/etc/di.xml`, result, 'utf8');
    };
    return new Promise((resolve, reject) => {
        const child = (0, child_process_1.spawn)('bin/composer require caravelx/module-graphql-config && bin/magento module:enable Caravel_GraphQlConfig && bin/magento setup:upgrade && bin/magento setup:di:compile && bin/magento setup:static-content:deploy -f', options);
        sp.start(picocolors_1.default.cyan((0, i18next_1.t)('command.generate_store.progress.graphql_start')));
        child.stdout.on('data', (data) => {
            writeLog(data.toString());
        });
        child.stderr.on('data', (data) => {
            writeLog(data.toString());
        });
        child.on('exit', async (code) => {
            console.log(picocolors_1.default.red(code));
            if (code === 0) {
                await increaseQueryDepthAndComplexity();
                sp.stop(picocolors_1.default.green((0, i18next_1.t)('command.generate_store.progress.graphql_end')));
                resolve(1);
            }
            else {
                sp.stop(picocolors_1.default.red((0, i18next_1.t)('command.generate_store.progress.graphql_failed')));
                (0, terminalHelpers_1.logSimpleInfoMessage)((0, i18next_1.t)('command.generate_store.magento.failed_log'));
                reject();
            }
        });
    });
};
exports.default = handleGraphQL;
//# sourceMappingURL=handleGraphQL.js.map