"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const i18next_1 = require("i18next");
const reasonable_filename_1 = tslib_1.__importDefault(require("reasonable-filename"));
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("../functions/terminalHelpers");
const project_name_1 = require("../../project-name");
const docker_1 = require("../docker");
/** Prompt user to enter Magento directory name */
const getMagentoDirName = async (message) => {
    const magentoDirName = await (0, prompts_1.text)({
        message,
        initialValue: 'magento',
        validate: (value) => {
            if (!(value === null || value === void 0 ? void 0 : value.trim())) {
                return (0, i18next_1.t)('domain.project_name.is_empty');
            }
            if (!(0, reasonable_filename_1.default)(value)) {
                return (0, i18next_1.t)('domain.project_name.is_not_directory');
            }
        }
    });
    if ((0, prompts_1.isCancel)(magentoDirName)) {
        (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
        process.exit(0);
    }
    const existingContainers = await (0, docker_1.checkExistingDockerContainers)((0, project_name_1.formatToProjectName)(magentoDirName));
    if (existingContainers) {
        return getMagentoDirName((0, i18next_1.t)('command.generate_store.magento.docker_exists'));
    }
    return (0, project_name_1.formatToProjectName)(magentoDirName);
};
exports.default = getMagentoDirName;
//# sourceMappingURL=getMagentoDirName.js.map