"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const i18next_1 = require("i18next");
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("../functions/terminalHelpers");
/** Gets a Magento domain name and checks for validity. */
const getMagentoDomainName = async (message) => {
    const magentoDomainName = await (0, prompts_1.text)({
        message,
        initialValue: 'magento.test',
        validate(value) {
            if (!(value === null || value === void 0 ? void 0 : value.trim())) {
                return (0, i18next_1.t)('domain.project_name.is_empty');
            }
            const domainNameRegex = 
            // eslint-disable-next-line no-useless-escape
            /^((?!-))(xn--)?[a-z0-9][a-z0-9-_]{0,61}[a-z0-9]{0,1}\.(xn--)?([a-z0-9\-]{1,61}|[a-z0-9-]{1,30}\.[a-z]{2,})$/;
            if (!domainNameRegex.test(value)) {
                return (0, i18next_1.t)('command.generate_store.magento.invalid_domain');
            }
        }
    });
    if ((0, prompts_1.isCancel)(magentoDomainName)) {
        (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
        process.exit(0);
    }
    return magentoDomainName;
};
exports.default = getMagentoDomainName;
//# sourceMappingURL=getMagentoDomain.js.map