"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prompts_1 = require("@clack/prompts");
const terminalHelpers_1 = require("../functions/terminalHelpers");
const i18next_1 = require("i18next");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const homeDir = require('os').homedir();
/** Handle input for Magento 2 access keys */
const handleMagentoKeys = async () => {
    const accessKey = await (0, prompts_1.password)({
        message: (0, i18next_1.t)('command.generate_store.magento.access_key')
    });
    const secretKey = await (0, prompts_1.password)({
        message: (0, i18next_1.t)('command.generate_store.magento.secret_key')
    });
    if ((0, prompts_1.isCancel)(accessKey || secretKey)) {
        (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)('command.generate_store.message.canceled'));
        process.exit(0);
    }
    // creating auth.json file in home directory for composer
    await new Promise((resolve) => {
        //  if .composer directory does not exist, create it
        if (!fs_1.default.existsSync(path_1.default.join(homeDir, '.composer'))) {
            fs_1.default.mkdirSync(path_1.default.join(homeDir, '.composer'));
        }
        // check if file exists
        if (fs_1.default.existsSync(path_1.default.join(homeDir, '.composer', 'auth.json'))) {
            // read file
            const authFile = fs_1.default.readFileSync(path_1.default.join(homeDir, '.composer', 'auth.json'), 'utf-8');
            // parse JSON
            const authJson = JSON.parse(authFile);
            // check if keys are already in file
            authJson['http-basic'] = {
                'repo.magento.com': {
                    username: accessKey,
                    password: secretKey
                }
            };
            // write file
            fs_1.default.writeFileSync(path_1.default.join(homeDir, '.composer', 'auth.json'), JSON.stringify(authJson, null, 2), 'utf-8');
        }
        else {
            // create file
            const authJson = {
                'http-basic': {
                    'repo.magento.com': {
                        username: accessKey,
                        password: secretKey
                    }
                },
                'bitbucket-oauth': {},
                'github-oauth': {},
                'gitlab-oauth': {},
                'gitlab-token': {},
                bearer: {}
            };
            fs_1.default.writeFileSync(path_1.default.join(homeDir, '.composer', 'auth.json'), JSON.stringify(authJson, null, 2), 'utf-8');
        }
        resolve(1);
    });
    return {
        accessKey: accessKey,
        secretKey: secretKey
    };
};
exports.default = handleMagentoKeys;
//# sourceMappingURL=handleMagentoKeys.js.map